@@ -378,6 +378,16 @@ public:
 			return s_.empty();
 		}
 
+		constexpr bool operator ==(iterator const& op) const
+		{
+			return s_.size() == op.s_.size();
+		}
+
+		constexpr bool operator !=(iterator const& op) const
+		{
+			return s_.size() != op.s_.size();
+		}
+
 		constexpr value_type operator*() const
 		{
 			return s_.substr(0, pos_);
