@@ -429,7 +429,7 @@ private:
 public:
 	/// Gets the current point in time time
 	static monotonic_clock now() {
-		return monotonic_clock(clock_type::now());
+		return monotonic_clock(std::chrono::time_point_cast<std::chrono::milliseconds>(clock_type::now()));
 	}
 
 	explicit operator bool() const {
